@@ -6,7 +6,7 @@ module Openwsman
   class Transport
       def Transport.auth_request_callback( client, auth_type )
 	puts "Transport.auth_request_callback( #{client}, #{auth_type} )"
-	puts Transport.auth_name( 1 )
+	puts Transport.auth_name( auth_type )
 	puts "#{Transport.auth_name( auth_type )} authentication failed for #{client.host}"
 	print "Username:"
 	STDOUT.flush
@@ -14,8 +14,7 @@ module Openwsman
 	print "Password:"
 	STDOUT.flush
 	password = STDIN.gets.chomp
-	return [ username, password ] if auth_type == BASIC_AUTH
-	return nil     # abort, if non-basic auth
+	return [ username, password ]
       end
   end
 end
