@@ -1,11 +1,9 @@
 # cim_computer_system.rb
 #  enumerate/pull/release for CIM_OperatingSystem
 
-$:.unshift "../../../build/bindings/ruby"
-$:.unshift "../.libs"
-
 require 'test/unit'
 require 'rexml/document'
+require File.join(File.dirname(__FILE__),'_loadpath')
 require 'openwsman'
 require '_client'
 
@@ -15,7 +13,7 @@ class WsmanTest < Test::Unit::TestCase
     assert client
     options = Openwsman::ClientOptions.new
     assert options
-#    options.flags = Openwsman::ClientOption::DUMP_REQUEST
+#    options.set_dump_request
     uri = "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_OperatingSystem"
 #    uri = "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_HostedService"
 #    uri = "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_CommMechanismForManager"
