@@ -2,13 +2,10 @@
 # Tests an openwsman 2.2 extension: Intrinsic WBEM operations via 'invoke'
 #
 
-$:.unshift "../../../bindings/ruby"
-$:.unshift "../../../build/bindings/ruby"
-$:.unshift "../.libs"
-
 require 'test/unit'
 require 'rexml/document'
-require 'openwsman/openwsman'
+require File.join(File.dirname(__FILE__),'_loadpath')
+require 'openwsman'
 require '_client'
 
 class WsmanTest < Test::Unit::TestCase
@@ -20,6 +17,8 @@ class WsmanTest < Test::Unit::TestCase
     options.set_dump_request
     
 #    options.selectors = { Openwsman::CIM_NAMESPACE_SELECTOR => "cimv2/interop" }
+    # enable this line to get *all* (child) classes
+#    options.add_selector "DeepInheritance", 1
     
     method = Openwsman::CIM_ACTION_ENUMERATE_CLASS_NAMES
     uri = Openwsman::XML_NS_CIM_INTRINSIC
