@@ -43,9 +43,10 @@
 #ifndef WS_XML_SERIALIZER_H
 #define WS_XML_SERIALIZER_H
 
+#include <time.h>
+
 #include "wsman-types.h"
 #include "wsman-names.h"
-#include "u/libu.h"
 
 // Errors
 #define WS_ERR_INSUFFICIENT_RESOURCES	(-1)
@@ -155,12 +156,6 @@ struct __XmlSerializerInfo
 };
 typedef struct __XmlSerializerInfo XmlSerializerInfo;
 
-struct __WsSerializerContext
-{
-	pthread_mutex_t lock;
-	list_t *WsSerializerAllocList;
-};
-
 typedef struct __WsSerializerContext *WsSerializerContextH;
 
 #define SER_IN            0x8000
@@ -362,9 +357,13 @@ typedef struct __WsSerializerContext *WsSerializerContextH;
 #define SER_STR(n, x)                 SER_STR_FLAGS(n, x, 0)
 #define SER_STRUCT(n, x, t)           SER_STRUCT_FLAGS(n, x, 0, t)
 #define SER_DYN_ARRAY(n, mn, mx, t)   SER_DYN_ARRAY_FLAGS(n, mn, mx, 0, t)
+#define SER_NS_INT8(ns, n, x)         SER_NS_INT8_FLAGS(ns, n, x, 0)
 #define SER_NS_UINT8(ns, n, x)        SER_NS_UINT8_FLAGS(ns, n, x, 0)
+#define SER_NS_INT16(ns, n, x)        SER_NS_INT16_FLAGS(ns, n, x, 0)
 #define SER_NS_UINT16(ns, n, x)       SER_NS_UINT16_FLAGS(ns, n, x, 0)
+#define SER_NS_INT32(ns, n, x)        SER_NS_INT32_FLAGS(ns, n, x, 0)
 #define SER_NS_UINT32(ns, n, x)       SER_NS_UINT32_FLAGS(ns, n, x, 0)
+#define SER_NS_INT64(ns, n, x)        SER_NS_INT64_FLAGS(ns, n, x, 0)
 #define SER_NS_UINT64(ns, n, x)       SER_NS_UINT64_FLAGS(ns, n, x, 0)
 #define SER_NS_REAL32(ns, n, x)       SER_NS_REAL32_FLAGS(ns, n, x, 0)
 #define SER_NS_REAL64(ns, n, x)       SER_NS_REAL64_FLAGS(ns, n, x, 0)
