@@ -46,8 +46,10 @@
 #include <curl/curl.h>
 #include <curl/easy.h>
 
+#ifdef ENABLE_EVENTING_SUPPORT
 #include <openssl/opensslv.h>
 #include <openssl/ssl.h>
+#endif
 
 #include "u/libu.h"
 #include "wsman-types.h"
@@ -270,6 +272,8 @@ init_curl_transport(WsManClient *cl)
 	CURLcode r = CURLE_OK;
         char *sslhack;
         long sslversion;
+        dictionary *ini = iniparser_new(wsmc_get_conffile(cl));
+
 #define curl_err(str)  debug("Error = %d (%s); %s", \
 		r, curl_easy_strerror(r), str);
 	curl = curl_easy_init();
@@ -278,6 +282,15 @@ init_curl_transport(WsManClient *cl)
 		debug("Could not init easy curl");
 		goto DONE;
 	}
+        // client:curlopt_nosignal
+        if (ini) {
+          int nosignal = iniparser_getint(ini, "client:curlopt_nosignal", 0);
+          r = curl_easy_setopt(curl, CURLOPT_NOSIGNAL, nosignal);
+          if (r != 0) {
+            curl_err("curl_easy_setopt(CURLOPT_NOSIGNAL) failed");
+            goto DONE;
+          }
+        }
 	debug("cl->authentication.verify_peer: %d", cl->authentication.verify_peer );
 	// verify peer
 	r = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, wsman_transport_get_verify_peer(cl)?1:0);
@@ -311,17 +324,13 @@ init_curl_transport(WsManClient *cl)
 	}
 	
 	if (0 != cl->authentication.verify_peer && 0 != cl->authentication.crl_check)
-	{
-		dictionary *ini = NULL;
-		
+	{		
 		if (cl->authentication.crl_file == NULL)
 		{
-			ini = iniparser_new(cl->client_config_file);
 			if (ini != NULL)
 			{
 			        char *crlfile = iniparser_getstr(ini, "client:crlfile");
 				wsman_transport_set_crlfile(cl, crlfile);
-			        iniparser_free(ini);
 			}
 		}
 		if (cl->authentication.crl_file != NULL)
@@ -406,10 +415,12 @@ init_curl_transport(WsManClient *cl)
           goto DONE;
         }
 
+        iniparser_free(ini);
 	return (void *)curl;
  DONE:
 	cl->last_error = convert_to_last_error(r);
 	curl_easy_cleanup(curl);
+        iniparser_free(ini);
 	return NULL;
 #undef curl_err
 }
@@ -435,6 +446,7 @@ wsmc_handler( WsManClient *cl,
 	char *_user = NULL, *_pass = NULL;
 	u_buf_t *response = NULL;
 	//char *soapaction;
+	char *tmp_str = NULL;
 
 	if (!cl->initialized && wsmc_transport_init(cl, NULL)) {
 		cl->last_error = WS_LASTERR_FAILED_INIT;
@@ -471,7 +483,8 @@ wsmc_handler( WsManClient *cl,
 	char content_type[64];
 	snprintf(content_type, 64, "Content-Type: application/soap+xml;charset=%s", cl->content_encoding);
 	headers = curl_slist_append(headers, content_type);
-	usag = malloc(12 + strlen(wsman_transport_get_agent(cl)) + 1);
+	tmp_str = wsman_transport_get_agent(cl);
+	usag = malloc(12 + strlen(tmp_str) + 1);
 	if (usag == NULL) {
 		r = CURLE_OUT_OF_MEMORY;
 		cl->fault_string = u_strdup("Could not malloc memory");
@@ -479,7 +492,8 @@ wsmc_handler( WsManClient *cl,
 		goto DONE;
 	}
 
-	sprintf(usag, "User-Agent: %s", wsman_transport_get_agent(cl));
+	sprintf(usag, "User-Agent: %s", tmp_str);
+	free(tmp_str);
 	headers = curl_slist_append(headers, usag);
 
 #if 0
@@ -614,6 +628,7 @@ wsmc_handler( WsManClient *cl,
 					 */
 					r = 67;
 #endif
+                    cl->fault_string = u_strdup(curl_easy_strerror(r));
                     curl_err("user/password wrong or empty.");
 		    break;
                 }
