@@ -490,7 +490,7 @@ xml_parser_ns_add(WsXmlNodeH node, const char *uri, const char *prefix)
                          */
 			if (xmlNs == NULL && strcmp(prefix,"xml") == 0
                             && strcmp(uri, (const char *)XML_XML_NAMESPACE) == 0) {
-				xmlNs = (xmlNsPtr) u_zalloc(sizeof(xmlNs));
+				xmlNs = (xmlNsPtr) u_zalloc(sizeof(*xmlNs));
 				if (xmlNs == NULL) {
 					error("Couldn't create a new Namespace structure");	
 					return(NULL);
@@ -903,11 +903,9 @@ int xml_parser_check_xpath(WsXmlDocH doc, const char *expression)
 
 			retval = 1;
 		}
-		xmlXPathFreeContext(ctxt);
 		xmlXPathFreeObject(obj);
-	} else {
-		return 0;
 	}
+	xmlXPathFreeContext(ctxt);
 
 	return retval;
 }
@@ -946,11 +944,9 @@ char *xml_parser_get_xpath_value(WsXmlDocH doc, const char *expression)
 					xmlChildrenNode,
 					1);
 
-		xmlXPathFreeContext(ctxt);
 		xmlXPathFreeObject(obj);
-	} else {
-		return NULL;
 	}
+	xmlXPathFreeContext(ctxt);
 
 	return result;
 }
