@@ -120,6 +120,8 @@ ServerConfig *wsman_server_create_config(char *config_file)
 		soap = ws_context_get_runtime(cntx);
 		if (listener)
 			soap->listener = (WsManListenerH *)listener;
+	} else {
+		u_free(listener);
 	}
 	//debug_add_handler (debug_message_handler, DEBUG_LEVEL_ALWAYS, NULL);
 	return (ServerConfig *)soap;
