@@ -163,11 +163,7 @@ static void wsman_expiretime2xmldatetime(unsigned long expire, char *str)
 {
 	time_t t = expire;
 	struct tm tm;
-	int gmtoffset_hour;
-	int gmtoffset_minute;
 	localtime_r(&t, &tm);
-	gmtoffset_hour = 0;
-	gmtoffset_minute = 0;
 	snprintf(str, 30, "%u-%u%u-%u%uT%u%u:%u%u:%u%u+%u%u:%u%u",
 			tm.tm_year + 1900, (tm.tm_mon + 1)/10, (tm.tm_mon + 1)%10,
 			tm.tm_mday/10, tm.tm_mday%10, tm.tm_hour/10, tm.tm_hour%10,
@@ -762,6 +758,7 @@ wsman_identify_stub(SoapOpH op,
 		ws_serialize(cntx->serializercntx, ws_xml_get_soap_body(doc), data, typeInfo,
 			WSMID_IDENTIFY_RESPONSE, (char *) info->data, NULL, 1);
 		ws_serializer_free_mem(cntx->serializercntx, data, typeInfo);
+                u_free(data);
 	}
 
 	if (doc) {
@@ -1084,6 +1081,8 @@ wsenum_release_stub(SoapOpH op,
 	enumInfo = get_locked_enuminfo(soapCntx, _doc,
 		op, WSENUM_RELEASE, &status);
 
+        ws_set_context_xml_doc_val(soapCntx, WSFW_INDOC, _doc);
+
 	if (enumInfo == NULL) {
 		doc = wsman_generate_fault( _doc,
 			status.fault_code, status.fault_detail_code, NULL);
@@ -1831,7 +1830,6 @@ wse_unsubscribe_stub(SoapOpH op, void *appData, void *opaqueData)
 	WsSubscribeInfo *subsInfo = NULL;
 	WsmanStatus     status;
 	WsXmlNodeH      inNode;
-	WsXmlNodeH      body;
 	WsXmlNodeH      header;
 	SoapH           soap = soap_get_op_soap(op);
 	WsContextH soapCntx = ws_get_soap_context(soap);
@@ -1844,7 +1842,6 @@ wse_unsubscribe_stub(SoapOpH op, void *appData, void *opaqueData)
 
 	epcntx = ws_create_ep_context(soap, _doc);
 	wsman_status_init(&status);
-	body = ws_xml_get_soap_body(_doc);
 	header = ws_xml_get_soap_header(_doc);
 	inNode = ws_xml_get_child(header, 0, XML_NS_EVENTING, WSEVENT_IDENTIFIER);
 	if(inNode == NULL) {
@@ -2104,7 +2101,10 @@ static int wse_send_notification(WsEventThreadContextH cntx, WsXmlDocH outdoc, W
 	else { //WSMAN_SECURITY_PROFILE_HTTP_SPNEGO_KERBEROS_TYPE
 	}
 	wsmc_transport_init(notificationSender, NULL);
-	wsman_send_request(notificationSender, outdoc);
+	if (wsman_send_request(notificationSender, outdoc)) {
+                warning("wse_send_notification: wsman_send_request fails for endpoint %s", subsInfo->epr_notifyto);
+                /* FIXME: retVal */
+        }
 	if(acked) {
 		retVal = WSE_NOTIFICATION_NOACK;
 		WsXmlDocH ackdoc = wsmc_build_envelope_from_response(notificationSender);
@@ -2141,7 +2141,7 @@ static void * wse_event_sender(void * thrdcntx, unsigned char flag)
 	WsEventThreadContextH threadcntx = (WsEventThreadContextH)thrdcntx;
 	WsSubscribeInfo * subsInfo = threadcntx->subsInfo;
 	if(flag == 1)
-		debug("wse_notification_sender for %s stated", subsInfo->subsId);
+		debug("wse_notification_sender for %s started", subsInfo->subsId);
 	else
 		debug("wse_heartbeat_sender for %s started", subsInfo->subsId);
 	WsXmlDocH notificationDoc = NULL;
